$TITLE  Model M2x2x1_act: Illustraiton of activity analysis

$ontext
This example introduces nonlinear activity analysis where different
technologies produce the same output and may be operated or not depending
on their profitability.

Activity Y3 is unprofitable at initial equilibrium prices.  It is
therefore not operated, and we cannot infer its technical properties
from the benchmark social accounting data.  

In situations like this, we must use other information such as
engineering cost estimates to specify the unobserved technology.
Here, we will assume that Y3 is very similar to sector Y2 but
uses lambda times the inputs of Y2 to produce the same output
lambda >= 1
$offtext

$if not setglobal modus		$setglobal modus	NO_SLACK
$if not setglobal lambda	$setglobal lambda	1.1


TABLE BENCH(*,*)  Observed benchmark financial flows 
*	Activity Y3 is initially slack
                Y1     Y2       CONS		
        Y1      40		-40	
        Y2             40	-40	
        L     -20     -10        30    
        K     -20     -30        50  ;


SET     I       Produced goods          /Y1, Y2/,
        F       Factors of production   /L, K/;

ALIAS (I,J), (F,FF);

SCALAR	LAMBDA		Inefficiency of Y3 production /%LAMBDA%/;


PARAMETER	TAX(I)		Production output tax;	

TAX(I) = 0;


PARAMETER       Y0(I)           Benchmark sectoral output,
                FD0(F,I)        Benchmark factor demands,
                C0(I)           Benchmark consumption demand, 
		K0		Capital endowment,
		L0		Labor endowment,
		ALPHA(F,I)      Factor input benchmark value share,
                BETA(I)         Benchmark consumption value share
		M0		Benchmark income of representative agent;


*       Extract values from table
Y0(I)		= BENCH(I,I);          
FD0(F,I)	= -BENCH(F,I);
C0(I)		= -BENCH(I,"CONS");       

K0		= BENCH("K","CONS");     
L0		= BENCH("L","CONS");     
M0		= K0 + L0;

ALPHA(F,I)	= FD0(F,I) / Y0(I);
BETA(I)		= C0(I) / M0;



DISPLAY Y0, FD0, C0, ALPHA, BETA;




POSITIVE VARIABLES
        Y(I)		Production activity level
	Y3		Slack activity
        p(I)		Commodity price 
        w		Wage rate
	r		Rental rate

	M		Consumer income level

EQUATIONS
        PRF_Y(I)	Zero profit in production
	PRF_Y3		Y3 zero profit condition

        MKT_Y(I)	Supply-demand balance for commodities
        MKT_L		Supply-demand balance for labor
        MKT_K		Supply-demand balance for capital


        RA_M		Income definition for RA;



SET AA_SET(I) /Y2/;

*       Zero profit conditions are produced for all of the production
*       sectors.  These are interpreted as:

*               Cost of Production Gross of Tax  =  Value of Output

PRF_Y(I)..         Y0(I) *(w*(1+TAX(I)))**alpha("L",I)* (r*(1+TAX(I)))**alpha("K",I)  =E= Y0(I) * P(I);

PRF_Y3..	   LAMBDA*( w**alpha("L","Y2") * r**alpha("K","Y2"))      =E=  P("Y2");

*       Market clearance conditions for each of the final goods and
*       primary factors.  These are interpreted as:

*               Output plus Initial Endowment  = Intermediate + Final Demand

MKT_Y(I)..		Y0(I) * Y(I) + Y3$AA_SET(I)  =E= C0(I) * M/(P(I)*M0);

MKT_L..		L0  =E= SUM(I, FD0("L",I)* Y(I) * P(I)/(w*(1+TAX(I))) ) + Y3*alpha("L","Y2")*P("Y2")/w  ;

MKT_K..		K0  =E= SUM(I, FD0("K",I)* Y(I) * P(I)/(r*(1+TAX(I))) ) + Y3*alpha("K","Y2")*P("Y2")/r ;


*       Income balance states that the level of expenditure (RA)
*       equals the value of factor income plus tax revenue:

RA_M..		M =E=	L0*w + K0*r 
			 + SUM(I, w*TAX(I)* (FD0("L",I)* Y(I) * P(I)/(w*(1+TAX(I)))))
			 + SUM(I, r*TAX(I)* (FD0("K",I)* Y(I) * P(I)/(r*(1+TAX(I)))));


MODEL M2x2x1_act /PRF_Y.Y, PRF_Y3.Y3, MKT_Y.P, MKT_L.w, MKT_K.r, RA_M.M /;

*	Choose price of labor as the numeraire
w.FX	= 1;

*       Check the benchmark (benchmark replication):
*	Slack acticity level is zero initially
Y.L(I)=1; Y3.L=0;  P.L(I)=1; r.L=1; M.L=M0;

M2x2x1_act.ITERLIM = 0;
SOLVE M2x2x1_act USING MCP;


*	Proceed with Tax Counterfactual

M2x2x1_act.ITERLIM = 1000;
SCALAR	AA	Flag for activity analysis /0/; 
$if %modus%==SLACK	AA=1;

AA=1;
Y3.FX$(NOT AA)	= 0;


SET SC		Tax scenarios	/T0, T05, T10, T15, T20, T25, T30, T35, T40, T45, T50/;

PARAMETERS	
		TAXLEVEL(SC)	Ad valorem tax rate /T0 0, T05 5, T10 10, T15 15, T20 20, T25 25, T30 30, T35 35, T40 40, T45 45, T50 50/,
		REVENUE(SC)	Revenue report parameter,
		WELFARE(SC)	Welfare implications as percentage change in HEV of income;

LOOP (SC,
	TAX("Y2") = TAXLEVEL(SC)/100;
SOLVE M2x2x1_act USING MCP; 
REVENUE(SC)   = 	 [EPS + SUM(I, w.L*TAX(I)* (FD0("L",I)* Y.L(I) * P.L(I)/(w.L*(1+TAX(I)))))
			 + SUM(I, r.L*TAX(I)* (FD0("K",I)* Y.L(I) * P.L(I)/(r.L*(1+TAX(I)))))] / PROD(I,P.L(I)**BETA(I));
WELFARE(SC)	=	ROUND(100*((M.L/(PROD(I,P.L(I)**BETA(I))))/M0 - 1), 1);
);

DISPLAY REVENUE, WELFARE;
